==> haskell-text-latin1-0.3.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-latin1
version: 0.3.1
id: text-latin1-0.3.1-9Jk52ccaV4CGspJYZunZZU
key: text-latin1-0.3.1-9Jk52ccaV4CGspJYZunZZU
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-latin1
synopsis: Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.
category: Text
abi: 25ef556efd9083780f95c1d4b5280bc7
exposed: True
exposed-modules:
    Text.Ascii Text.Latin1
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-latin1-0.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-latin1-0.3.1
hs-libraries: HStext-latin1-0.3.1-9Jk52ccaV4CGspJYZunZZU
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    data-checked-0.3-Co0QNKLSvAXGWCJmpJNVMt
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html: /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-latin1-0.3.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-latin1
version: 0.3.1
id: text-latin1-0.3.1-F9gMENqLhQUKEeqgV2t8rB
key: text-latin1-0.3.1-F9gMENqLhQUKEeqgV2t8rB
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-latin1
synopsis: Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.
category: Text
abi: 7c9f108e22f6e3abf9a795e6a09910db
exposed: True
exposed-modules:
    Text.Ascii Text.Latin1
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-latin1-0.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-latin1-0.3.1
hs-libraries: HStext-latin1-0.3.1-F9gMENqLhQUKEeqgV2t8rB
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    data-checked-0.3-Co0QNKLSvAXGWCJmpJNVMt
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html: /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
